@@ -1,5 +1,5 @@
 package Apache::AuthCookie::Params::CGI;
-$Apache::AuthCookie::Params::CGI::VERSION = '3.26';
+$Apache::AuthCookie::Params::CGI::VERSION = '3.28';
 # ABSTRACT: Internal CGI Params Subclass
 
 use strict;
@@ -174,13 +174,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Apache::AuthCookie::Params::CGI - Internal CGI Params Subclass
 
 =head1 VERSION
 
-version 3.26
+version 3.28
 
 =head1 SYNOPSIS
 
@@ -188,7 +190,7 @@ version 3.26
 
 =head1 DESCRIPTION
 
-This is a pure perl implmentation of HTTP/CGI parameter processing for Apache::AuthCookie.
+This is a pure perl implementation of HTTP/CGI parameter processing for Apache::AuthCookie.
 
 =head1 METHODS
 
@@ -229,7 +231,7 @@ Set the given CGI field value to the given values.  Existing values will be repl
 
 =head2 params(): Hash::MultiValue
 
-Get the underlying CGI paramters.  This is a merged version of
+Get the underlying CGI parameters.  This is a merged version of
 L<query_params()> and L<body_params()>.
 
 =head2 query_params(): Hash::MultiValue
@@ -251,13 +253,17 @@ header is not present.
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/mschout/apache-authcookie>
-and may be cloned from L<git://github.com/mschout/apache-authcookie.git>
+The development version is on github at L<https://https://github.com/mschout/apache-authcookie>
+and may be cloned from L<git://https://github.com/mschout/apache-authcookie.git>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to bug-apache-authcookie@rt.cpan.org or through the web interface at:
- http://rt.cpan.org/Public/Dist/Display.html?Name=Apache-AuthCookie
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/mschout/apache-authcookie/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
